# Installation

At the command line:

    $ pip install redflag

Or, if you use Conda environments:

    $ conda create -n redflag python=3.9
    $ conda activate redflag
    $ pip install redflag

For developers, there are also options for installing `tests`, `docs` and `dev` dependencies, e.g. `pip install redflag[dev]` to install all testing and documentation packages.

If you want to help develop Redflag, please read [Development](development.md).
